==> v2.4.0.tar.gz: badgen/preview/preview.md <==
# badgen preview

## Colors

![](/color/blue/blue)
![](/color/cyan/cyan)
![](/color/green/green)
![](/color/yellow/yellow)
![](/color/orange/orange)
![](/color/red/red)
![](/color/pink/pink)
![](/color/purple/purple)
![](/color/grey/grey)
![](/color/black/black)

## Default Style

| Badge | URL |
| --- | --- |
|![](/▲/Déjà%20vu/purple) | [/▲/Déjà%20vu/purple](/▲/Déjà%20vu/purple) |
|![](/chat/on%20gitter/cyan) | [/chat/on%20gitter/cyan](/chat/on%20gitter/cyan) |
|![](/style/standard/f2a) | [/style/standard/f2a](/style/standard/f2a) |
|![](/license/Apache-2.0/blue) | [/license/Apache-2.0/blue](/license/Apache-2.0/blue) |
|![](/Language/Swift%203.0.1/orange) | [/Language/Swift%203.0.1/orange](/Language/Swift%203.0.1/orange) |

## Flat Style

| Badge (flat) | URL |
| --- | --- |
|![](/▲/Déjà%20vu/purple?style=flat) | [/▲/Déjà%20vu/purple?style=flat](/▲/Déjà%20vu/purple?style=flat) |
|![](/chat/on%20gitter/cyan?style=flat) | [/chat/on%20gitter/cyan?style=flat](/chat/on%20gitter/cyan?style=flat) |
|![](/style/standard/f2a?style=flat) | [/style/standard/f2a?style=flat](/style/standard/f2a?style=flat) |
|![](/license/Apache-2.0/blue?style=flat) | [/license/Apache-2.0/blue?style=flat](/license/Apache-2.0/blue?style=flat) |
|![](/Language/Swift%203.0.1/orange?style=flat) | [/Language/Swift%203.0.1/orange?style=flat](/Language/Swift%203.0.1/orange?style=flat) |

## Astral Plain Charset (emoji)

| Badge | URL |
| --- | --- |
|![](/emoji/💩🤱🦄/DDD?emoji=1) | [/emoji/💩🤱🦄/DDD?emoji=1](/emoji/💩🤱🦄/DDD?emoji=1) |
|![](/emoji/💩🤱🦄/DDD?style=flat&emoji=1) | [/emoji/💩🤱🦄/DDD?style=flat&emoji=1](/emoji/💩🤱🦄/DDD?style=flat&emoji=1) |

## Icon

| Badge | URL |
| --- | --- |
| ![](/docker/badge?icon=1) | [/docker/badge?icon=1](/docker/badge?icon=1)
| ![](/docker/badge?icon=1&style=flat) | [/docker/badge?icon=1&style=flat](/docker/badge?icon=1&style=flat)

==> v2.4.5.tar.gz: badgen/preview/preview.md <==
# badgen preview

## Colors

![](/color/blue/blue)
![](/color/cyan/cyan)
![](/color/green/green)
![](/color/yellow/yellow)
![](/color/orange/orange)
![](/color/red/red)
![](/color/pink/pink)
![](/color/purple/purple)
![](/color/grey/grey)
![](/color/black/black)

## Default Style

| Badge | URL |
| --- | --- |
|![](/▲/déjà%20vu/purple) | [/▲/déjà%20vu/purple](/▲/déjà%20vu/purple) |
|![](/chat/on%20gitter/cyan) | [/chat/on%20gitter/cyan](/chat/on%20gitter/cyan) |
|![](/style/standard/f2a) | [/style/standard/f2a](/style/standard/f2a) |
|![](/license/Apache-2.0/blue) | [/license/Apache-2.0/blue](/license/Apache-2.0/blue) |
|![](/Language/Swift%203.0.1/orange) | [/Language/Swift%203.0.1/orange](/Language/Swift%203.0.1/orange) |

## Flat Style

| Badge (flat) | URL |
| --- | --- |
|![](/▲/déjà%20vu/purple?style=flat) | [/▲/déjà%20vu/purple?style=flat](/▲/déjà%20vu/purple?style=flat) |
|![](/chat/on%20gitter/cyan?style=flat) | [/chat/on%20gitter/cyan?style=flat](/chat/on%20gitter/cyan?style=flat) |
|![](/style/standard/f2a?style=flat) | [/style/standard/f2a?style=flat](/style/standard/f2a?style=flat) |
|![](/license/Apache-2.0/blue?style=flat) | [/license/Apache-2.0/blue?style=flat](/license/Apache-2.0/blue?style=flat) |
|![](/Language/Swift%203.0.1/orange?style=flat) | [/Language/Swift%203.0.1/orange?style=flat](/Language/Swift%203.0.1/orange?style=flat) |

## Astral Plain Charset (emoji)

| Badge | URL |
| --- | --- |
|![](/emoji/💩🤱🦄/DDD) | [/emoji/💩🤱🦄/DDD](/emoji/💩🤱🦄/DDD) |
|![](/emoji/💩🤱🦄/DDD?style=flat) | [/emoji/💩🤱🦄/DDD?style=flat](/emoji/💩🤱🦄/DDD?style=flat) |

## Icon

| Badge | URL |
| --- | --- |
| ![](http://localhost:3000//badge?icon=chrome) | [//badge?icon=chrome](http://localhost:3000//badge?icon=chrome)
| ![](/icon/badge?icon=chrome) | [/icon/badge?icon=chrome](/icon/badge?icon=chrome)
| ![](/icon/badge?icon=chrome&style=flat) | [/icon/badge?icon=chrome&style=flat](/icon/badge?icon=chrome&style=flat)
| ![](/icon/badge?icon=lgtm&iconWidth=19&style=flat) | [/icon/badge?icon=lgtm&iconWidth=19&style=flat](/icon/badge?icon=lgtm&iconWidth=19&style=flat)


## Edge Cases

![](/<{[(&)]}>/<{[(&)]}>)
